<?php

defined('HOSTCMS') || exit('HostCMS: access denied.');

/**
 * Показ структуры сайта.
 *
 * Доступные методы:
 *
 * - parentId($parentId) идентификатор родительского узла, по умолчанию 0
 * - level($level) выводить узлы структуры только до уровня вложенности $level
 * - showProperties(TRUE|FALSE) выводить значения дополнительных свойств усзлов структуры, по умолчанию FALSE
 * - showInformationsystemGroups(TRUE|FALSE) выводить связанные с узлом структуры группы информационной системы, по умолчанию FALSE
 * - showInformationsystemItems(TRUE|FALSE) выводить связанные с узлом структуры информационные элементы, по умолчанию FALSE
 * - showShopGroups(TRUE|FALSE) выводить связанные с узлом структуры группы магазина, по умолчанию FALSE
 * - showShopItems(TRUE|FALSE) выводить связанные с узлом структуры товары, по умолчанию FALSE
 * - showInformationsystemGroupProperties(TRUE|FALSE|array()) выводить значения дополнительных свойств групп информационной системы, по умолчанию FALSE
 * - showInformationsystemItemProperties(TRUE|FALSE|array()) выводить значения дополнительных свойств информационных элементов, по умолчанию FALSE
 * - showShopGroupProperties(TRUE|FALSE|array()) выводить значения дополнительных свойств групп магазина, по умолчанию FALSE
 * - showShopItemProperties(TRUE|FALSE|array()) выводить значения дополнительных свойств товаров, по умолчанию FALSE
 * - showShopItemAssociated(TRUE|FALSE) выводить сопутствующие товары, по умолчанию FALSE
 * - forbiddenTags(array('name')) массив тегов узла структуры, запрещенных к передаче в генерируемый XML
 * - cache(TRUE|FALSE) использовать кэширование, по умолчанию TRUE
 * - showPanel(TRUE|FALSE) показывать панель быстрого редактирования, по умолчанию TRUE
 * - onStep(3000) количество элементов, выбираемых запросом за 1 шаг, по умолчанию 500
 *
 * Доступные свойства:
 *
 * - currentStructureId идентификатор узла структуры
 *
 * <code>
 * Hostdev_Menu_Controller_Show = new Hostdev_Menu_Controller_Show(
 * 		Core_Entity::factory('Structure_Menu', 1)
 * 	);
 *
 * 	Hostdev_Menu_Controller_Show
 * 		->xsl(
 * 			Core_Entity::factory('Xsl')->getByName('Меню')
 * 		)
 * 		->show();
 * </code>

 * Hostdev Menu
 *
 * @Version 1.0
 * @author Eugeny Panikarowsky - evgenii_panikaro@mail.ru
 * @copyright © 2018 Eugeny Panikarowsky
 * $url http://hostdev.pw/
 *
*/
class Hostdev_Menu_Controller_Show extends Structure_Controller_Show
{

	/**
	 * Cache name
	 * @var string
	 */
	protected $_cacheName = 'hostdev_menu_show';

	/**
	 * Constructor.
	 * @param Site_Model $oMenu Structure_Menu
	 */
	public function __construct(Structure_Menu_Model $oMenu)
	{
		parent::__construct($oMenu->site->clearEntities());

		if (isset($this->_allowedProperties['menu'])) {
			unset($this->_allowedProperties['menu']);
		}
		if (isset($this->_propertiesValues['menu'])) {
			unset($this->_propertiesValues['menu']);
		}

		$this->addEntity($oMenu);

		$this->_Structure
			->queryBuilder()
			->leftJoin('hostdev_menu_structure_for_menus', 'hostdev_menu_structure_for_menus.structure_id', '=', 'structures.id',
				array(
					array('AND' => array('hostdev_menu_structure_for_menus.structure_menu_id ', '=', $oMenu->id))
				)

			)
			->where('hostdev_menu_structure_for_menus.id', 'NOT', NULL);

	}
}