<?php

defined('HOSTCMS') || exit('HostCMS: access denied.');

/**
 * Hostdev Menu
 *
 * @Version 1.0
 * @author Eugeny Panikarowsky - evgenii_panikaro@mail.ru
 * @copyright © 2018 Eugeny Panikarowsky
 * $url http://hostdev.pw/
 *
*/
class HostDev_Menu_Structure_For_Menu_Model extends Core_Entity
{
	/**
	 * Disable markDeleted()
	 * @var mixed
	 */
	protected $_marksDeleted = NULL;

	/**
	 * Belongs to relations
	 * @var array
	 */
	protected $_belongsTo = array(
		'structure' => array(),
		'structure_menu' => array()
	);

	/**
	 * Constructor.
	 * @param int $id entity ID
	 */
	public function __construct($id = NULL)
	{
		parent::__construct($id);

		if (is_null($id) && !$this->loaded())
		{
			$oUserCurrent = Core_Entity::factory('User', 0)->getCurrent();
			$this->_preloadValues['user_id'] = is_null($oUserCurrent) ? 0 : $oUserCurrent->id;
		}
	}

	/**
	 * Разрешить узел структуры $structure_id меню $structure_menu_id
	 *
	 * <code>
	 * $oShop->Shop_Item_Property_For_Groups->allowAccess($structure_menu_id, $structure_id);
	 * </code>
	 * @param int $structure_menu_id property ID
	 * @param int $structure_id group ID
	 * @return self
	 */
	public function allowAccess($structure_menu_id, $structure_id)
	{
		// Разрешаем доп. св-во для группы
		$oHostDev_Menu_Structure_For_Menu = $this->getByMenuIdAndStructureId($structure_menu_id, $structure_id);

		if (is_null($oHostDev_Menu_Structure_For_Menu))
		{
			$oHostDev_Menu_Structure_For_Menu = Core_Entity::factory('HostDev_Menu_Structure_For_Menu');
			$oHostDev_Menu_Structure_For_Menu->structure_id = $structure_id;
			$oHostDev_Menu_Structure_For_Menu->structure_menu_id = $structure_menu_id;
			$oHostDev_Menu_Structure_For_Menu->save();
		}
		return $this;
	}

	/**
	 * Get element by property ID and group ID
	 * @param int $structure_menu_id property ID
	 * @param int $structure_id group ID
	 * @return self|NULL
	 */
	public function getByMenuIdAndStructureId($structure_menu_id, $structure_id)
	{
		$structure_menu_id = intval($structure_menu_id);
		$structure_id = intval($structure_id);

		$this
			->queryBuilder()
			->where('structure_id', '=', $structure_id)
			->where('structure_menu_id', '=', $structure_menu_id)
			->limit(1);

		$aShop_Item_Property_For_Group = $this->findAll(FALSE);

		return isset($aShop_Item_Property_For_Group[0])
			? $aShop_Item_Property_For_Group[0]
			: NULL;
	}
}